{#
    bizstyle/layout.html
    ~~~~~~~~~~~~~~~~~~~~

    Sphinx layout template for the bizstyle theme.

    :copyright: Copyright 2011-2014 by Sphinx team, see AUTHORS.
    :license: BSD, see LICENSE for details.
#}
{% extends "basic/layout.html" %}

{% set script_files = script_files + ["_static/bizstyle.js"] %}

{# put the sidebar before the body #}
{% block sidebar1 %}{{ sidebar() }}{% endblock %}
{% block sidebar2 %}{% endblock %}

{# doctype override #}
{%- block doctype %}
<!doctype html>
{%- endblock %}

{%- block extrahead %}
    <meta name="viewport" content="width=device-width,initial-scale=1.0">
    <!--[if lt IE 9]>
    <script type="text/javascript" src="_static/css3-mediaqueries.js"></script>
    <![endif]-->
{%- endblock %}
